@@ -9,18 +9,14 @@ import (
 	"github.com/stretchr/testify/assert"
 )
 
-const tagsOutput = `v0.34
-v0.33
-v0.32.2
-v0.32.1
-v0.32
-testtag
+const tagsOutput = `tag1 this is my message
+tag2
+tag3 this is my other message
 `
 
 func TestGetTags(t *testing.T) {
 	type scenario struct {
 		testName      string
-		gitVersion    *GitVersion
 		runner        *oscommands.FakeCmdObjRunner
 		expectedTags  []*models.Tag
 		expectedError error
@@ -28,48 +24,20 @@ func TestGetTags(t *testing.T) {
 
 	scenarios := []scenario{
 		{
-			testName:   "should return no tags if there are none",
-			gitVersion: &GitVersion{2, 7, 0, ""},
+			testName: "should return no tags if there are none",
 			runner: oscommands.NewFakeRunner(t).
-				Expect(`git tag --list --sort=-creatordate`, "", nil),
+				Expect(`git tag --list -n --sort=-creatordate`, "", nil),
 			expectedTags:  []*models.Tag{},
 			expectedError: nil,
 		},
 		{
-			testName:   "should return no tags if there are none (< 2.7.0)",
-			gitVersion: &GitVersion{2, 6, 7, ""},
+			testName: "should return tags if present",
 			runner: oscommands.NewFakeRunner(t).
-				Expect(`git tag --list --sort=-v:refname`, "", nil),
-			expectedTags:  []*models.Tag{},
-			expectedError: nil,
-		},
-		{
-			testName:   "should return tags if present",
-			gitVersion: &GitVersion{2, 7, 0, ""},
-			runner: oscommands.NewFakeRunner(t).
-				Expect(`git tag --list --sort=-creatordate`, tagsOutput, nil),
+				Expect(`git tag --list -n --sort=-creatordate`, tagsOutput, nil),
 			expectedTags: []*models.Tag{
-				{Name: "v0.34"},
-				{Name: "v0.33"},
-				{Name: "v0.32.2"},
-				{Name: "v0.32.1"},
-				{Name: "v0.32"},
-				{Name: "testtag"},
-			},
-			expectedError: nil,
-		},
-		{
-			testName:   "should return tags if present (< 2.7.0)",
-			gitVersion: &GitVersion{2, 6, 7, ""},
-			runner: oscommands.NewFakeRunner(t).
-				Expect(`git tag --list --sort=-v:refname`, tagsOutput, nil),
-			expectedTags: []*models.Tag{
-				{Name: "v0.34"},
-				{Name: "v0.33"},
-				{Name: "v0.32.2"},
-				{Name: "v0.32.1"},
-				{Name: "v0.32"},
-				{Name: "testtag"},
+				{Name: "tag1", Message: "this is my message"},
+				{Name: "tag2", Message: ""},
+				{Name: "tag3", Message: "this is my other message"},
 			},
 			expectedError: nil,
 		},
@@ -78,11 +46,10 @@ func TestGetTags(t *testing.T) {
 	for _, scenario := range scenarios {
 		scenario := scenario
 		t.Run(scenario.testName, func(t *testing.T) {
-			loader := NewTagLoader(
-				utils.NewDummyCommon(),
-				scenario.gitVersion,
-				oscommands.NewDummyCmdObjBuilder(scenario.runner),
-			)
+			loader := &TagLoader{
+				Common: utils.NewDummyCommon(),
+				cmd:    oscommands.NewDummyCmdObjBuilder(scenario.runner),
+			}
 
 			tags, err := loader.GetTags()
 
