@@ -25,10 +25,25 @@ func (gui *Gui) resetControllers() {
 
 	rebaseHelper := helpers.NewMergeAndRebaseHelper(helperCommon, gui.State.Contexts, gui.git, refsHelper)
 	suggestionsHelper := helpers.NewSuggestionsHelper(helperCommon, model, gui.refreshSuggestions)
-	setCommitMessage := gui.getSetTextareaTextFn(func() *gocui.View { return gui.Views.CommitMessage })
-	getSavedCommitMessage := func() string {
-		return gui.State.savedCommitMessage
+	setCommitSummary := gui.getCommitMessageSetTextareaTextFn(func() *gocui.View { return gui.Views.CommitMessage })
+	setCommitDescription := gui.getCommitMessageSetTextareaTextFn(func() *gocui.View { return gui.Views.CommitDescription })
+	getCommitSummary := func() string {
+		return strings.TrimSpace(gui.Views.CommitMessage.TextArea.GetContent())
 	}
+
+	getCommitDescription := func() string {
+		return strings.TrimSpace(gui.Views.CommitDescription.TextArea.GetContent())
+	}
+	commitsHelper := helpers.NewCommitsHelper(helperCommon,
+		gui.State.Model,
+		gui.State.Contexts,
+		getCommitSummary,
+		setCommitSummary,
+		getCommitDescription,
+		setCommitDescription,
+		gui.RenderCommitLength,
+	)
+	gpgHelper := helpers.NewGpgHelper(helperCommon, gui.os, gui.git)
 	gui.helpers = &helpers.Helpers{
 		Refs:           refsHelper,
 		Host:           helpers.NewHostHelper(helperCommon, gui.git),
@@ -36,9 +51,9 @@ func (gui *Gui) resetControllers() {
 		Bisect:         helpers.NewBisectHelper(helperCommon, gui.git),
 		Suggestions:    suggestionsHelper,
 		Files:          helpers.NewFilesHelper(helperCommon, gui.git, osCommand),
-		WorkingTree:    helpers.NewWorkingTreeHelper(helperCommon, gui.git, gui.State.Contexts, refsHelper, model, setCommitMessage, getSavedCommitMessage),
+		WorkingTree:    helpers.NewWorkingTreeHelper(helperCommon, gui.git, gui.State.Contexts, refsHelper, model, setCommitSummary, commitsHelper, gpgHelper),
 		Tags:           helpers.NewTagsHelper(helperCommon, gui.git),
-		GPG:            helpers.NewGpgHelper(helperCommon, gui.os, gui.git),
+		GPG:            gpgHelper,
 		MergeAndRebase: rebaseHelper,
 		MergeConflicts: helpers.NewMergeConflictsHelper(helperCommon, gui.State.Contexts, gui.git),
 		CherryPick: helpers.NewCherryPickHelper(
@@ -48,7 +63,9 @@ func (gui *Gui) resetControllers() {
 			func() *cherrypicking.CherryPicking { return gui.State.Modes.CherryPicking },
 			rebaseHelper,
 		),
-		Upstream: helpers.NewUpstreamHelper(helperCommon, model, suggestionsHelper.GetRemoteBranchesSuggestionsFunc),
+		Upstream:    helpers.NewUpstreamHelper(helperCommon, model, suggestionsHelper.GetRemoteBranchesSuggestionsFunc),
+		AmendHelper: helpers.NewAmendHelper(helperCommon, gui.git, gpgHelper),
+		Commits:     commitsHelper,
 	}
 
 	gui.CustomCommandsClient = custom_commands.NewClient(
@@ -81,24 +98,12 @@ func (gui *Gui) resetControllers() {
 
 	bisectController := controllers.NewBisectController(common)
 
-	getCommitMessage := func() string {
-		return strings.TrimSpace(gui.Views.CommitMessage.TextArea.GetContent())
-	}
-
-	onCommitAttempt := func(message string) {
-		gui.State.savedCommitMessage = message
-		gui.Views.CommitMessage.ClearTextArea()
-	}
-
-	onCommitSuccess := func() {
-		gui.State.savedCommitMessage = ""
-	}
-
 	commitMessageController := controllers.NewCommitMessageController(
 		common,
-		getCommitMessage,
-		onCommitAttempt,
-		onCommitSuccess,
+	)
+
+	commitDescriptionController := controllers.NewCommitDescriptionController(
+		common,
 	)
 
 	remoteBranchesController := controllers.NewRemoteBranchesController(common)
@@ -109,8 +114,7 @@ func (gui *Gui) resetControllers() {
 	filesController := controllers.NewFilesController(
 		common,
 		gui.enterSubmodule,
-		setCommitMessage,
-		getSavedCommitMessage,
+		setCommitSummary,
 	)
 	mergeConflictsController := controllers.NewMergeConflictsController(common)
 	remotesController := controllers.NewRemotesController(
@@ -133,7 +137,12 @@ func (gui *Gui) resetControllers() {
 	patchBuildingController := controllers.NewPatchBuildingController(common)
 	snakeController := controllers.NewSnakeController(common, func() *snake.Game { return gui.snakeGame })
 
-	setSubCommits := func(commits []*models.Commit) { gui.State.Model.SubCommits = commits }
+	setSubCommits := func(commits []*models.Commit) {
+		gui.Mutexes.SubCommitsMutex.Lock()
+		defer gui.Mutexes.SubCommitsMutex.Unlock()
+
+		gui.State.Model.SubCommits = commits
+	}
 
 	for _, context := range []controllers.CanSwitchToSubCommits{
 		gui.State.Contexts.Branches,
@@ -239,6 +248,10 @@ func (gui *Gui) resetControllers() {
 		commitMessageController,
 	)
 
+	controllers.AttachControllers(gui.State.Contexts.CommitDescription,
+		commitDescriptionController,
+	)
+
 	controllers.AttachControllers(gui.State.Contexts.RemoteBranches,
 		remoteBranchesController,
 	)
