@@ -86,6 +86,11 @@ func (self *BranchesController) GetKeybindings(opts types.KeybindingsOpts) []*ty
 			Handler:     self.checkSelectedAndReal(self.fastForward),
 			Description: self.c.Tr.FastForward,
 		},
+		{
+			Key:         opts.GetKey(opts.Config.Branches.CreateTag),
+			Handler:     self.checkSelected(self.createTag),
+			Description: self.c.Tr.LcCreateTag,
+		},
 		{
 			Key:         opts.GetKey(opts.Config.Commits.ViewResetOptions),
 			Handler:     self.checkSelected(self.createResetMenu),
@@ -363,6 +368,10 @@ func (self *BranchesController) fastForward(branch *models.Branch) error {
 	})
 }
 
+func (self *BranchesController) createTag(branch *models.Branch) error {
+	return self.helpers.Tags.CreateTagMenu(branch.FullRefName(), func() {})
+}
+
 func (self *BranchesController) createResetMenu(selectedBranch *models.Branch) error {
 	return self.helpers.Refs.CreateGitResetMenu(selectedBranch.Name)
 }
