@@ -74,12 +74,6 @@ func (self *Gui) GetInitialKeybindings() ([]*types.Binding, []*gocui.ViewMouseBi
 			Modifier: gocui.ModNone,
 			Handler:  self.handleTopLevelReturn,
 		},
-		{
-			ViewName: "",
-			Key:      opts.GetKey(opts.Config.Universal.ReturnAlt1),
-			Modifier: gocui.ModNone,
-			Handler:  self.handleTopLevelReturn,
-		},
 		{
 			ViewName:    "",
 			Key:         opts.GetKey(opts.Config.Universal.OpenRecentRepos),
@@ -145,17 +139,19 @@ func (self *Gui) GetInitialKeybindings() ([]*types.Binding, []*gocui.ViewMouseBi
 			Description: self.c.Tr.LcRefresh,
 		},
 		{
-			ViewName:    "",
-			Key:         opts.GetKey(opts.Config.Universal.OptionMenu),
-			Handler:     self.handleCreateOptionsMenu,
-			Description: self.c.Tr.LcOpenMenu,
-			OpensMenu:   true,
+			ViewName:  "",
+			Key:       opts.GetKey(opts.Config.Universal.OptionMenu),
+			Handler:   self.handleCreateOptionsMenu,
+			OpensMenu: true,
 		},
 		{
 			ViewName: "",
 			Key:      opts.GetKey(opts.Config.Universal.OptionMenuAlt1),
 			Modifier: gocui.ModNone,
-			Handler:  self.handleCreateOptionsMenu,
+			// we have the description on the alt key and not the main key for legacy reasons
+			// (the original main key was 'x' but we've reassigned that to other purposes)
+			Description: self.c.Tr.LcOpenMenu,
+			Handler:     self.handleCreateOptionsMenu,
 		},
 		{
 			ViewName:    "status",
@@ -211,6 +207,12 @@ func (self *Gui) GetInitialKeybindings() ([]*types.Binding, []*gocui.ViewMouseBi
 			Handler:     self.handleCopySelectedSideContextItemToClipboard,
 			Description: self.c.Tr.LcCopyBranchNameToClipboard,
 		},
+		{
+			ViewName:    "remoteBranches",
+			Key:         opts.GetKey(opts.Config.Universal.CopyToClipboard),
+			Handler:     self.handleCopySelectedSideContextItemToClipboard,
+			Description: self.c.Tr.LcCopyBranchNameToClipboard,
+		},
 		{
 			ViewName:    "commits",
 			Key:         opts.GetKey(opts.Config.Universal.CopyToClipboard),
@@ -356,7 +358,7 @@ func (self *Gui) GetInitialKeybindings() ([]*types.Binding, []*gocui.ViewMouseBi
 			Description: self.c.Tr.LcCopySubmoduleNameToClipboard,
 		},
 		{
-			ViewName:    "files",
+			ViewName:    "",
 			Key:         opts.GetKey(opts.Config.Universal.ToggleWhitespaceInDiffView),
 			Handler:     self.toggleWhitespaceInDiffView,
 			Description: self.c.Tr.ToggleWhitespaceInDiffView,
