@@ -277,7 +277,7 @@ func displayCommit(
 	} else {
 		if len(commit.Tags) > 0 {
 			tagString = theme.DiffTerminalColor.SetBold().Sprint(strings.Join(commit.Tags, " ")) + " "
-		} else if commit.ExtraInfo != "" {
+		} else if common.UserConfig.Gui.ExperimentalShowBranchHeads && commit.ExtraInfo != "" {
 			tagString = style.FgMagenta.SetBold().Sprint("(*)") + " "
 		}
 	}
