@@ -1,6 +1,8 @@
 package style
 
 import (
+	"os"
+
 	"github.com/gookit/color"
 )
 
@@ -25,6 +27,23 @@ import (
 // a string, we derive it when a new TextStyle is created and store it in the
 // `style` field.
 
+// See https://github.com/xtermjs/xterm.js/issues/4238
+// VSCode is soon to fix this in an upcoming update.
+// Once that's done, we can scrap the HIDE_UNDERSCORES variable
+var (
+	underscoreEnvChecked bool
+	hideUnderscores      bool
+)
+
+func hideUnderScores() bool {
+	if !underscoreEnvChecked {
+		hideUnderscores = os.Getenv("TERM_PROGRAM") == "vscode"
+		underscoreEnvChecked = true
+	}
+
+	return hideUnderscores
+}
+
 type TextStyle struct {
 	fg         *Color
 	bg         *Color
@@ -64,6 +83,10 @@ func (b TextStyle) SetBold() TextStyle {
 }
 
 func (b TextStyle) SetUnderline() TextStyle {
+	if hideUnderScores() {
+		return b
+	}
+
 	b.decoration.SetUnderline()
 	b.Style = b.deriveStyle()
 	return b
