@@ -47,7 +47,7 @@ func chineseTranslationSet() TranslationSet {
 		StagingTitle:                        "正在暂存",
 		MergingTitle:                        "正在合并",
 		NormalTitle:                         "正常",
-		CommitMessage:                       "提交信息",
+		CommitSummary:                       "提交信息",
 		CredentialsUsername:                 "用户名",
 		CredentialsPassword:                 "密码",
 		CredentialsPassphrase:               "输入 SSH 密钥的密码",
@@ -94,7 +94,7 @@ func chineseTranslationSet() TranslationSet {
 		LcNewBranch:                         "新分支",
 		LcDeleteBranch:                      "删除分支",
 		NoBranchesThisRepo:                  "此仓库中没有分支",
-		CommitMessageConfirm:                "{{.keyBindClose}}：关闭，{{.keyBindNewLine}}：新行，{{.keyBindConfirm}}：确认",
+		CommitMessageConfirm:                "{{.keyBindClose}}：关闭，{{.keyBindConfirm}}：确认",
 		CommitWithoutMessageErr:             "您必须编写提交消息才能进行提交",
 		CloseConfirm:                        "{{.keyBindClose}}：关闭，{{.keyBindConfirm}}：确认",
 		LcClose:                             "关闭",
@@ -102,7 +102,7 @@ func chineseTranslationSet() TranslationSet {
 		LcSquashDown:                        "向下压缩",
 		LcFixupCommit:                       "修正提交（fixup）",
 		NoCommitsThisBranch:                 "该分支没有提交",
-		YouNoCommitsToSquash:                "您没有提交可以压缩",
+		CannotSquashOrFixupFirstCommit:      "There's no commit below to squash into",
 		Fixup:                               "修正（fixup）",
 		SureFixupThisCommit:                 "您确定要“修正”此提交吗？它将合并到下面的提交中",
 		SureSquashThisCommit:                "您确定要将这个提交压缩到下面的提交中吗？",
@@ -201,8 +201,6 @@ func chineseTranslationSet() TranslationSet {
 		ReflogCommitsTitle:                  "Reflog 页面",
 		GlobalTitle:                         "全局键绑定",
 		ConflictsResolved:                   "已解决所有冲突。是否继续？",
-		RebasingTitle:                       "变基",
-		ConfirmRebase:                       "您确定要将分支 {{.checkedOutBranch}} 变基到 {{.selectedBranch}} 吗？",
 		ConfirmMerge:                        "您确定要将分支 {{.selectedBranch}} 合并到 {{.checkedOutBranch}} 吗？",
 		FwdNoUpstream:                       "此分支没有上游，无法快进",
 		FwdNoLocalUpstream:                  "此分支的远程未在本地注册，无法快进",
@@ -216,8 +214,6 @@ func chineseTranslationSet() TranslationSet {
 		LcPasteCommits:                      "粘贴提交（拣选）",
 		SureCherryPick:                      "您确定要将选中的提交进行拣选到这个分支吗？",
 		CherryPick:                          "拣选 (Cherry-Pick)",
-		CannotRebaseOntoFirstCommit:         "您不能以交互方式变基 (rebase) 至第一次提交",
-		CannotSquashOntoSecondCommit:        "您不能压缩 (squash) 或修正 (fixup) 第二个提交",
 		Donate:                              "捐助",
 		AskQuestion:                         "提问咨询",
 		PrevLine:                            "选择上一行",
@@ -395,7 +391,7 @@ func chineseTranslationSet() TranslationSet {
 		LcCreateNewBranchFromCommit:         "从提交创建新分支",
 		LcBuildingPatch:                     "正在构建补丁",
 		LcViewCommits:                       "查看提交",
-		MinGitVersionError:                  "Git 版本必须至少为 2.0（即从 2014 年开始的版本）。请更新 git。或者在 https://github.com/jesseduffield/lazygit/issues 上提出一个问题，以使 lazygit 更加向后兼容。",
+		MinGitVersionError:                  "Git 版本必须至少为 2.20（即从 2018 年开始的版本）。请更新 git。或者在 https://github.com/jesseduffield/lazygit/issues 上提出一个问题，以使 lazygit 更加向后兼容。",
 		LcRunningCustomCommandStatus:        "正在运行自定义命令",
 		LcSubmoduleStashAndReset:            "存放未提交的子模块更改和更新",
 		LcAndResetSubmodules:                "和重置子模块",
