@@ -6,7 +6,7 @@ import (
 )
 
 var Stash = NewIntegrationTest(NewIntegrationTestArgs{
-	Description:  "Stashing files",
+	Description:  "Stashing files directly (not going through the stash menu)",
 	ExtraCmdArgs: "",
 	Skip:         false,
 	SetupConfig:  func(config *config.AppConfig) {},
@@ -23,9 +23,7 @@ var Stash = NewIntegrationTest(NewIntegrationTestArgs{
 			Lines(
 				Contains("file"),
 			).
-			Press(keys.Files.ViewStashOptions)
-
-		t.ExpectPopup().Menu().Title(Equals("Stash options")).Select(MatchesRegexp("stash all changes$")).Confirm()
+			Press(keys.Files.StashAllChanges)
 
 		t.ExpectPopup().Prompt().Title(Equals("Stash changes")).Type("my stashed file").Confirm()
 
